/* See the end of this file for copyright, license, and warranty information. */

#pragma once

#include <arch/atomic.h>

#include <toolchain.h>

/**
 * Enter atomic context.
 *
 * Since Ardix does not support SMP, this method will simply increment a
 * reference counter that is checked in the scheduler interrupt routine before
 * performing the context switch.
 */
static __always_inline word_t atomic_enter(void)
{
	return _atomic_enter();
}

/** Leave atomic context. */
static __always_inline void atomic_restore(word_t context)
{
	_atomic_restore(context);
}

/** Return a nonzero value if the current process is in atomic context. */
static __always_inline int is_atomic(void)
{
	return _is_atomic();
}

/*
 * This file is part of Ardix.
 * Copyright (c) 2020, 2021 Felix Kopp <owo@fef.moe>.
 *
 * Ardix is non-violent software: you may only use, redistribute,
 * and/or modify it under the terms of the CNPLv6+ as found in
 * the LICENSE file in the source code root directory or at
 * <https://git.pixie.town/thufie/CNPL>.
 *
 * Ardix comes with ABSOLUTELY NO WARRANTY, to the extent
 * permitted by applicable law.  See the CNPLv6+ for details.
 */
